@@ -34,7 +34,7 @@ except AttributeError:
             pass
 
 __author__ = 'Alec Thomas <alec@swapoff.org>'
-__version__ = '0.7.0'
+__version__ = '0.7.1'
 __version_tag__ = ''
 
 log = logging.getLogger(__name__)
@@ -292,10 +292,9 @@ class Binder(object):
 
         :param module: A Module instance, Module subclass, or a function.
         """
-        if isinstance(module, Module):
-            module(self)
-        elif type(module) is type and issubclass(module, Module):
-            module()(self)
+        if type(module) is type and issubclass(module, Module):
+            instance = self.injector.create_object(module)
+            instance(self)
         else:
             bindings = getattr(module, '__bindings__', {})
             kwargs = self.injector.args_to_inject(module, bindings, module)
@@ -525,10 +524,11 @@ class Injector(object):
         self.binder.bind(Binder, to=self.binder)
         # Initialise modules
         for module in modules:
-            if isinstance(module, type):
-                module = module()
+            self.binder.install(module)
 
-            module(self.binder)
+    @property
+    def _log_prefix(self):
+        return '>' * (len(self._stack) + 1) + ' '
 
     def get(self, interface, annotation=None, scope=None):
         """Get an instance of the given interface.
@@ -552,8 +552,9 @@ class Injector(object):
             raise Error('%s; scopes must be explicitly bound '
                         'with Binder.bind_scope(scope_cls)' % e)
 
+        log.debug('%sGetting %r using %r', self._log_prefix, key, binding)
         result = scope_instance.get(key, binding.provider).get()
-        log.debug('get(%r, annotation=%r, scope=%r) -> %r', interface, annotation, scope, result)
+        log.debug('%sGot %r', self._log_prefix, result)
         return result
 
     def create_child_injector(self, *args, **kwargs):
@@ -561,8 +562,9 @@ class Injector(object):
 
     def create_object(self, cls, additional_kwargs=None):
         """Create a new instance, satisfying any dependencies on cls."""
-
         additional_kwargs = additional_kwargs or {}
+        log.debug('%sCreating %r object with %r', self._log_prefix, cls, additional_kwargs)
+
         instance = cls.__new__(cls)
         try:
             self.install_into(instance)
@@ -604,6 +606,8 @@ class Injector(object):
         def repr_key(k):
             return '%s.%s()' % tuple(map(_describe, k))
 
+        log.debug('%sProviding %r for %r', self._log_prefix, bindings, function)
+
         if key in self._stack:
             raise CircularDependency(
                 'circular dependency detected: %s -> %s' %
@@ -720,8 +724,8 @@ def inject(**bindings):
     def method_wrapper(f):
         for key, value in bindings.items():
             bindings[key] = BindingKey(value, None)
-        args = getargspec(f)
-        if args[0][0] == 'self':
+        argspec = getargspec(f)
+        if argspec.args and argspec.args[0] == 'self':
             @functools.wraps(f)
             def inject(self_, *args, **kwargs):
                 injector = getattr(self_, '__injector__', None)
